@@ -4,35 +4,18 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = 0.002;
+our $VERSION = 0.003;
 
 use bytes;
 use File::Map qw/map_anonymous/;
-use Data::Swap qw/swap/;
-use Readonly;
-use Exporter 5.57 qw/import/;
-
-our @EXPORT = qw/const/;
+use Sub::Exporter -setup => { exports => [qw/const/], groups => { default => [qw/const/] } };
 
 ## no critic (Subroutines::RequireArgUnpacking)
-sub _get_value {
-	if (@_ > 1) {
-		return $_[1];
-	}
-	else {
-		my $tmp;
-		swap(\$_[0], \$tmp);
-		return $tmp;
-	}
-}
-
 sub const {
-	for my $value (_get_value(@_)) {
-		map_anonymous $_[0], length $value;
-		substr $_[0], 0, length $value, $value;
-		utf8::decode($_[0]) if utf8::is_utf8($value);
-		Readonly $_[0];
-	}
+	map_anonymous $_[0], length $_[1];
+	substr $_[0], 0, length $_[1], $_[1];
+	utf8::decode($_[0]) if utf8::is_utf8($_[1]);
+	Internals::SvREADONLY($_[0], 1);
 	return;
 }
 
@@ -46,26 +29,25 @@ Thread::Const - Constant strings efficiently shared between threads
 
 =head1 VERSION
 
-Version 0.002
+Version 0.003
 
 =head1 SYNOPSIS
 
-    use Thread::Const;
-
-    const(my $foo = 'some very large string');
-    const my $bar, 'some other very large string';
+ use Thread::Const;
+ 
+ const my $bar => 'some other very large string';
 
 =head1 DESCRIPTION
 
-This module generates constant values that can be shared among threads. This may reduce memory usage because the variable won't be copied.
+This module generates constant strings that will be shared among threads. This may reduce memory usage because the variable won't be copied.
 
 =head1 FUNCTIONS
 
 This module defined one function, which it exports by default.
 
-=head2 const($string [, $value ])
+=head2 const($string, $value)
 
-Make $string a constant that will be shared between threads. If $value is defined it will be assigned to $string.
+Make $string a constant that will be shared between threads. $value will be assigned to $string.
 
 =head1 AUTHOR
 
@@ -77,6 +59,10 @@ Please report any bugs or feature requests to C<bug-thread-const at rt.cpan.org>
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Thread-Const>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
+=head1 SEE ALSO
+
+L<Const::Fast>, A more generalized const facility. Unless your strings are big you probably want to use that.
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
